# Larch Documentation

[![PyPI - Version](https://img.shields.io/pypi/v/larch)](https://pypi.org/project/larch)
[![conda-forge](https://img.shields.io/conda/dn/conda-forge/larch)](https://anaconda.org/conda-forge/larch)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/driftlesslabs/larch/ci.yml?branch=main)

🏆︁ Winner of the [AGIFORS 56th Annual Symposium Best Innovation award](http://agifors.org/Symposium).

This is the in-development documentation for Larch v6.

:::{warning}
This project is very much under development.  There are plenty of undocumented functions
and features; use them at your own risk.  Undocumented features may be non-functional,
not rigorously tested, deprecated or removed without notice in a future update.
:::

## User Guide

Information about using Larch, and more generally about working with discrete
choice models.

```{toctree}
:maxdepth: 2

user-guide/index
api/index
examples/index
```
